@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 require XSLoader;
 XSLoader::load('Class::XSAccessor::Array', $VERSION);
@@ -20,11 +20,14 @@ sub import {
   my $replace = $opts{replace} || 0;
   my $chained = $opts{chained} || 0;
 
-  my $read_subs = $opts{getters} || {};
-  my $set_subs  = $opts{setters} || {};
-  my $acc_subs  = $opts{accessors} || {};
-  my $pred_subs = $opts{predicates} || {};
+  my $read_subs      = $opts{getters} || {};
+  my $set_subs       = $opts{setters} || {};
+  my $acc_subs       = $opts{accessors} || {};
+  my $pred_subs      = $opts{predicates} || {};
   my $construct_subs = $opts{constructors} || [defined($opts{constructor}) ? $opts{constructor} : ()];  
+  my $true_subs      = $opts{true} || [];
+  my $false_subs     = $opts{false} || [];
+
 
   foreach my $subname (keys %$read_subs) {
     my $arrayIndex = $read_subs->{$subname};
@@ -49,6 +52,14 @@ sub import {
   foreach my $subname (@$construct_subs) {
     _generate_method($caller_pkg, $subname, "", $replace, $chained, "constructor");
   }
+  
+  foreach my $subname (@$true_subs) {
+    _generate_method($caller_pkg, $subname, "", $replace, $chained, "true");
+  }
+
+  foreach my $subname (@$false_subs) {
+    _generate_method($caller_pkg, $subname, "", $replace, $chained, "false");
+  }
 }
 
 sub _generate_method {
@@ -92,6 +103,12 @@ sub _generate_method {
   elsif ($type eq 'constructor') {
     newxs_constructor($subname);
   }
+  elsif ($type eq 'true') {
+    newxs_boolean($subname, 1);
+  }
+  elsif ($type eq 'false') {
+    newxs_boolean($subname, 0);
+  }
   else {
     newxs_accessor($subname, $arrayIndex, $chained);
   }
@@ -123,7 +140,10 @@ Class::XSAccessor::Array - Generate fast XS accessors without runtime compilatio
     },
     predicates => { # test for definedness
       has_buz => 2,
-    };
+    },
+    true => [ 'is_token', 'is_whitespace' ],
+    false => [ 'significant' ];
+  
   # The imported methods are implemented in fast XS.
   
   # normal class code here.
@@ -169,6 +189,12 @@ synopsis, you could have written C<MyClass::get_foo> instead
 of C<get_foo>. This way, you can install methods in classes other
 than the current class. See also: The C<class> option below.
 
+Since version 1.01, you can generate extremely simply methods which
+simply return true or false (and always do so). If that seems like a
+really superfluous thing to you, then think of a large class hierarchy
+with interfaces such as PPI. This is implemented as the C<true>
+and C<false> options, see synopsis.
+
 =head1 OPTIONS
 
 In addition to specifying the types and names of accessors, you can add options
